==> seedsui-react-5.7.30.tgz: package/lib/Location/Main/Choose/Current.js <==
import React, { forwardRef } from 'react';
import { activeItemTarget, centerToPoint } from "./../utils";
import Checkbox from "./../../../Checkbox";
import locale from "./../../../locale";
import Navigation from "./Navigation";

// 当前位置
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
function Current(_ref, ref) {
  var readOnly = _ref.readOnly,
    map = _ref.map,
    current = _ref.current,
    onChange = _ref.onChange;
  // 定位到当前位置
  function centerToCurrent() {
    if (current && current.longitude && current.latitude) {
      centerToPoint([current.longitude, current.latitude], {
        map: map,
        type: 'gcj02'
      });
    }
  }
  return /*#__PURE__*/_jsx("div", {
    className: "mappage-info-item",
    onClick: readOnly ? function () {
      centerToCurrent();
    } : function (e) {
      activeItemTarget(e.currentTarget);
      onChange(current, {
        type: 'gcj02',
        updateNearby: false
      });
    },
    ref: ref,
    children: /*#__PURE__*/_jsxs("div", {
      className: "mappage-info-item-content",
      children: [/*#__PURE__*/_jsxs("div", {
        className: "mappage-info-item-content-title",
        children: [/*#__PURE__*/_jsx("div", {
          className: "flex-1",
          children: locale('当前位置', 'current_location')
        }), /*#__PURE__*/_jsx(Navigation, {
          longitude: current === null || current === void 0 ? void 0 : current.longitude,
          latitude: current === null || current === void 0 ? void 0 : current.latitude,
          address: current === null || current === void 0 ? void 0 : current.value
        })]
      }), /*#__PURE__*/_jsxs("div", {
        className: "mappage-info-item-content-description",
        children: [/*#__PURE__*/_jsx("div", {
          className: "flex-1",
          children: (current === null || current === void 0 ? void 0 : current.value) || ''
        }), /*#__PURE__*/_jsx("div", {
          className: "mappage-info-item-checkbox",
          children: !readOnly && /*#__PURE__*/_jsx(Checkbox, {
            checked: true
          })
        })]
      })]
    })
  });
}
export default /*#__PURE__*/forwardRef(Current);

==> seedsui-react-5.7.84.tgz: package/lib/Location/Main/Choose/Current.js <==
import React, { forwardRef } from 'react';
import { activeItemTarget, centerToPoint } from "./../utils";
import Navigation from "./Navigation";

// 测试使用
// import { locale, Checkbox } from 'seedsui-react'
// 内库使用
import Checkbox from "./../../../Checkbox";
import locale from "./../../../locale";

// 当前位置
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
function Current(_ref, ref) {
  var readOnly = _ref.readOnly,
    map = _ref.map,
    current = _ref.current,
    onChange = _ref.onChange;
  // 定位到当前位置
  function centerToCurrent() {
    if (current && current.longitude && current.latitude) {
      centerToPoint([current.longitude, current.latitude], {
        map: map,
        type: 'gcj02'
      });
    }
  }
  return /*#__PURE__*/_jsx("div", {
    className: "mappage-info-item",
    onClick: readOnly ? function () {
      centerToCurrent();
    } : function (e) {
      activeItemTarget(e.currentTarget);
      onChange(current, {
        type: 'gcj02',
        updateNearby: false
      });
    },
    ref: ref,
    children: /*#__PURE__*/_jsxs("div", {
      className: "mappage-info-item-content",
      children: [/*#__PURE__*/_jsxs("div", {
        className: "mappage-info-item-content-title",
        children: [/*#__PURE__*/_jsx("div", {
          className: "flex-1",
          children: (current === null || current === void 0 ? void 0 : current.title) || locale('当前位置', 'current_location')
        }), /*#__PURE__*/_jsx(Navigation, {
          longitude: current === null || current === void 0 ? void 0 : current.longitude,
          latitude: current === null || current === void 0 ? void 0 : current.latitude,
          address: current === null || current === void 0 ? void 0 : current.value
        })]
      }), /*#__PURE__*/_jsxs("div", {
        className: "mappage-info-item-content-description",
        children: [/*#__PURE__*/_jsx("div", {
          className: "flex-1",
          children: (current === null || current === void 0 ? void 0 : current.value) || ''
        }), /*#__PURE__*/_jsx("div", {
          className: "mappage-info-item-checkbox",
          children: !readOnly && /*#__PURE__*/_jsx(Checkbox, {
            checked: true
          })
        })]
      })]
    })
  });
}
export default /*#__PURE__*/forwardRef(Current);
